<!-- Basic, proper reference link -->
[Link Text]: my-section "Link Title"

<!-- Link with extension -->
[Link Text]: my-section.md "Link Title"

<!-- Link without Title -->
[Link Text]: my-section

<!-- Title with optional newline -->
[Link Text]: my-section
"Test Newline Title"

<!-- Absolute Link -->
[Foo]: /other-project/project "Project"